@@ -1,6 +1,6 @@
-package Email::Sender::Transport::Failable;
+package Email::Sender::Transport::Failable 2.601;
 # ABSTRACT: a wrapper to makes things fail predictably
-$Email::Sender::Transport::Failable::VERSION = '1.300034';
+
 use Moo;
 extends 'Email::Sender::Transport::Wrapper';
 
@@ -61,7 +61,7 @@ Email::Sender::Transport::Failable - a wrapper to makes things fail predictably
 
 =head1 VERSION
 
-version 1.300034
+version 2.601
 
 =head1 DESCRIPTION
 
@@ -78,13 +78,23 @@ C<send>.
 
 If any coderef returns a true value, the value will be used to signal failure.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo Signes.
+This software is copyright (c) 2024 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
